@@ -8,16 +8,23 @@
 #' @usage \method{terms}{mpoly}(x, ...)
 #' @export
 #' @examples
-#' terms(mp('x^2 - y + x y z'))
-#' is.mpolyList( terms(mp('x^2 - y + x y z')) )
-#' str(unclass( terms(mp('x^2 - y + x y z')) ))
+#' 
+#' \dontrun{ .Deprecated issues a warning
+#' 
+#' x <- mp("x^2 - y + x y z")
+#' terms(x)
+#' monomials(x)
+#' 
+#' }
 #' 
 terms.mpoly <- function(x, ...){
-  mpolyList <- lapply(x, function(v){
-    l <- list(v)
-    class(l) <- 'mpoly'
-    l
-  })
-  class(mpolyList) <- 'mpolyList'
-  mpolyList
+  .Deprecated("monomials")
+  # mpolyList <- lapply(x, function(v){
+  #   l <- list(v)
+  #   class(l) <- 'mpoly'
+  #   l
+  # })
+  # class(mpolyList) <- 'mpolyList'
+  # mpolyList
+  monomials(x)
 }
